@@ -5,6 +5,8 @@ import (
 	"fmt"
 	"time"
 
+	"github.com/onsi/gomega"
+
 	corev1 "k8s.io/api/core/v1"
 	k8sv1 "k8s.io/api/core/v1"
 	apierrs "k8s.io/apimachinery/pkg/api/errors"
@@ -39,6 +41,14 @@ const (
 	HTTPSTinyCoreQcow2URL = "https://cdi-file-host.%s/tinyCore.qcow2"
 	// TinyCoreQcow2URLRateLimit provides a test url for the tineyCore qcow2 image via rate-limiting proxy
 	TinyCoreQcow2URLRateLimit = "http://cdi-file-host.%s:82/tinyCore.qcow2"
+	// HTTPSTinyCoreVmdkURL provides a test url for the tineyCore qcow2 image
+	HTTPSTinyCoreVmdkURL = "https://cdi-file-host.%s/tinyCore.vmdk"
+	// HTTPSTinyCoreVdiURL provides a test url for the tineyCore qcow2 image
+	HTTPSTinyCoreVdiURL = "https://cdi-file-host.%s/tinyCore.vdi"
+	// HTTPSTinyCoreVhdURL provides a test url for the tineyCore qcow2 image
+	HTTPSTinyCoreVhdURL = "https://cdi-file-host.%s/tinyCore.vhd"
+	// HTTPSTinyCoreVhdxURL provides a test url for the tineyCore qcow2 image
+	HTTPSTinyCoreVhdxURL = "https://cdi-file-host.%s/tinyCore.vhdx"
 	// InvalidQcowImagesURL provides a test url for invalid qcow images
 	InvalidQcowImagesURL = "http://cdi-file-host.%s/invalid_qcow_images/"
 	// LargeVirtualDiskQcow provides a test url for a cirros image with a large virtual size, in qcow2 format
@@ -57,6 +67,19 @@ const (
 	ImageioURL = "https://imageio.%s:12346/ovirt-engine/api"
 	// VcenterURL provides URL of vCenter/ESX simulator
 	VcenterURL = "https://vcenter.%s:8989/sdk"
+
+	// TinyCoreMD5 is the MD5 hash of first 100k bytes of tinyCore image
+	TinyCoreMD5 = "3710416a680523c7d07538cb1026c60c"
+	// TinyCoreTarMD5 is the MD5 hash of first 100k bytes of tinyCore tar image
+	TinyCoreTarMD5 = "aec1a39d753b4b7cc81ee02bc625a342"
+	// TinyCoreBlockMD5 is the MD5 hash of first 100k bytes of tinyCore image on block device
+	TinyCoreBlockMD5 = "d41d8cd98f00b204e9800998ecf8427e"
+	// ImageioMD5 is the MD5 hash of first 100k bytes of imageio image
+	ImageioMD5 = "91150be031835ccfac458744da57d4f6"
+	// VcenterMD5 is the MD5 hash of first 100k bytes of Vcenter image
+	VcenterMD5 = "91150be031835ccfac458744da57d4f6"
+	// BlankMD5 is the MD5 hash of first 100k bytes of blank image
+	BlankMD5 = "0019d23bef56a136a1891211d7007f6f"
 )
 
 // CreateDataVolumeFromDefinition is used by tests to create a testable Data Volume
@@ -94,6 +117,15 @@ func NewCloningDataVolume(dataVolumeName, size string, sourcePvc *k8sv1.Persiste
 
 // NewDataVolumeWithHTTPImport initializes a DataVolume struct with HTTP annotations
 func NewDataVolumeWithHTTPImport(dataVolumeName string, size string, httpURL string) *cdiv1.DataVolume {
+	claimSpec := &k8sv1.PersistentVolumeClaimSpec{
+		AccessModes: []k8sv1.PersistentVolumeAccessMode{k8sv1.ReadWriteOnce},
+		Resources: k8sv1.ResourceRequirements{
+			Requests: k8sv1.ResourceList{
+				k8sv1.ResourceStorage: resource.MustParse(size),
+			},
+		},
+	}
+
 	return &cdiv1.DataVolume{
 		ObjectMeta: metav1.ObjectMeta{
 			Name:        dataVolumeName,
@@ -105,14 +137,34 @@ func NewDataVolumeWithHTTPImport(dataVolumeName string, size string, httpURL str
 					URL: httpURL,
 				},
 			},
-			PVC: &k8sv1.PersistentVolumeClaimSpec{
-				AccessModes: []k8sv1.PersistentVolumeAccessMode{k8sv1.ReadWriteOnce},
-				Resources: k8sv1.ResourceRequirements{
-					Requests: k8sv1.ResourceList{
-						k8sv1.ResourceName(k8sv1.ResourceStorage): resource.MustParse(size),
-					},
+			PVC: claimSpec,
+		},
+	}
+}
+
+// NewDataVolumeWithHTTPImportAndStorageSpec initializes a DataVolume struct with HTTP annotations
+func NewDataVolumeWithHTTPImportAndStorageSpec(dataVolumeName string, size string, httpURL string) *cdiv1.DataVolume {
+	storageSpec := &cdiv1.StorageSpec{
+		AccessModes: []k8sv1.PersistentVolumeAccessMode{k8sv1.ReadWriteOnce},
+		Resources: k8sv1.ResourceRequirements{
+			Requests: k8sv1.ResourceList{
+				k8sv1.ResourceStorage: resource.MustParse(size),
+			},
+		},
+	}
+
+	return &cdiv1.DataVolume{
+		ObjectMeta: metav1.ObjectMeta{
+			Name:        dataVolumeName,
+			Annotations: map[string]string{},
+		},
+		Spec: cdiv1.DataVolumeSpec{
+			Source: cdiv1.DataVolumeSource{
+				HTTP: &cdiv1.DataVolumeSourceHTTP{
+					URL: httpURL,
 				},
 			},
+			Storage: storageSpec,
 		},
 	}
 }
@@ -461,3 +513,18 @@ func PersistentVolumeClaimFromDataVolume(datavolume *cdiv1.DataVolume) *corev1.P
 		Spec: *datavolume.Spec.PVC,
 	}
 }
+
+// GetCloneType returnc the CDI clone type
+func GetCloneType(clientSet *cdiclientset.Clientset, dataVolume *cdiv1.DataVolume) string {
+	var cloneType string
+	gomega.Eventually(func() bool {
+		dv, err := clientSet.CdiV1beta1().DataVolumes(dataVolume.Namespace).Get(context.TODO(), dataVolume.Name, metav1.GetOptions{})
+		gomega.Expect(err).ToNot(gomega.HaveOccurred())
+		val, ok := dv.Annotations["cdi.kubevirt.io/cloneType"]
+		if ok {
+			cloneType = val
+		}
+		return ok
+	}, 90*time.Second, 2*time.Second).Should(gomega.BeTrue())
+	return cloneType
+}
